[Qa-jenkins-scm] [jenkins.debian.net] 01/01: reproducible: raise limit how many packages people can schedule per day to 200

Holger Levsen holger at moszumanska.debian.org
Fri Aug 21 15:52:17 UTC 2015


This is an automated email from the git hooks/post-receive script.

holger pushed a commit to branch master
in repository jenkins.debian.net.

commit 4b0737c36db71d3a2636f2d10aa62b30bfc2f8fa
Author: Holger Levsen <holger at layer-acht.org>
Date:   Fri Aug 21 17:52:08 2015 +0200

    reproducible: raise limit how many packages people can schedule per day to 200
---
 bin/reproducible_remote_scheduler.py | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/bin/reproducible_remote_scheduler.py b/bin/reproducible_remote_scheduler.py
index 0572bb4..04424ce 100755
--- a/bin/reproducible_remote_scheduler.py
+++ b/bin/reproducible_remote_scheduler.py
@@ -213,7 +213,7 @@ date = (now - time_delta).strftime('%Y-%m-%d %H:%M')
 log.debug('date_scheduled = ' + date + ' time_delta = ' + str(time_delta))
 
 
 # a single person can't schedule more than 50 packages in the same day; this
 # is actually easy to bypass, but let's give some trust to the Debian people
 query = '''SELECT count(*) FROM manual_scheduler
            WHERE requester = "{}" AND date_request > "{}"'''
@@ -222,7 +222,7 @@ try:
 except IndexError:
     amount = 0
 log.debug(requester + ' already scheduled ' + str(amount) + ' packages today')
-if amount + len(ids) > 50 and not local:
+if amount + len(ids) > 200 and not local:
     log.error(bcolors.FAIL + 'You have exceeded the maximum number of manual ' +
               'reschedulings allowed for a day. Please ask in ' +
               '#debian-reproducible if you need to schedule more packages.' +
@@ -213,7 +213,7 @@ date = (now - time_delta).strftime('%Y-%m-%d %H:%M')
 
 
-# a single person can't schedule more than 50 packages in the same day; this
+# a single person can't schedule more than 200 packages in the same day; this
 # is actually easy to bypass, but let's give some trust to the Debian people
 query = '''SELECT count(*) FROM manual_scheduler

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/qa/jenkins.debian.net.git



More information about the Qa-jenkins-scm mailing list